"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VelocitySensor = void 0;
var utils_1 = require("../utils");
var VelocitySensor = /** @class */ (function () {
    function VelocitySensor(devAddr, mcuId) {
        this.types = ['TimeDomainDataInfo', 'RMSSpeedStatus', 'AccPeakStatus', 'FreqData'];
        this.devAddr = undefined;
        this.mcuId = undefined;
        this.statuses = ['GOOD', 'WARNING', 'ALARM'];
        this.MAX_VALUE = 5.0;
        if (devAddr)
            this.devAddr = devAddr;
        if (mcuId)
            this.mcuId = mcuId;
    }
    VelocitySensor.prototype.getRandomStatus = function () {
        return this.statuses[(0, utils_1.randomNumberInRange)(0, this.statuses.length - 1)];
    };
    VelocitySensor.prototype.setDevAddr = function (devAddr) {
        this.devAddr = devAddr;
    };
    VelocitySensor.prototype.setMcuId = function (mcuId) {
        this.mcuId = mcuId;
    };
    VelocitySensor.prototype.getDevAddr = function () {
        return (this.devAddr ? this.devAddr : undefined);
    };
    VelocitySensor.prototype.getMcuId = function () {
        return (this.mcuId ? this.mcuId : undefined);
    };
    VelocitySensor.prototype.getTimeDomainDataInfo = function () {
        if (!this.devAddr || !this.mcuId) {
            throw 'Missing DevAddr or MCU_ID!';
        }
        return {
            DevAddr: this.devAddr,
            Type: this.types[0],
            MCU_ID: this.mcuId,
            Data: {
                X_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                X_RMS_Speed: (0, utils_1.randomNumberInRange)(0, this.MAX_VALUE, false),
                Y_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Y_RMS_Speed: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Z_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Z_RMS_Speed: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false)
            }
        };
    };
    VelocitySensor.prototype.getRMSSpeedStatus = function () {
        if (!this.devAddr || !this.mcuId) {
            throw 'Missing DevAddr or MCU_ID!';
        }
        return {
            DevAddr: this.devAddr,
            Type: this.types[1],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_Unit: "mm/s" },
                { Y_Status: this.getRandomStatus(), Y_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_Unit: "mm/s" },
                { Z_Status: this.getRandomStatus(), Z_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_Unit: "mm/s" },
            ]
        };
    };
    VelocitySensor.prototype.getAccPeakStatus = function () {
        if (!this.devAddr || !this.mcuId) {
            throw 'Missing DevAddr or MCU_ID!';
        }
        return {
            DevAddr: this.devAddr,
            Type: this.types[2],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_AccPeakUnit: "m/s^2" },
                { Y_Status: this.getRandomStatus(), Y_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_AccPeakUnit: "m/s^2" },
                { Z_Status: this.getRandomStatus(), Z_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_AccPeakUnit: "m/s^2" },
            ]
        };
    };
    VelocitySensor.prototype.getFreqData = function () {
        if (!this.devAddr || !this.mcuId) {
            throw 'Missing DevAddr or MCU_ID!';
        }
        return {
            DevAddr: this.devAddr,
            Type: this.types[3],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), X_Max_FreqUnit: "Hz" },
                { Y_Status: this.getRandomStatus(), Y_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), Y_Max_FreqUnit: "Hz" },
                { Z_Status: this.getRandomStatus(), Z_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), Z_Max_FreqUnit: "Hz" },
            ]
        };
    };
    VelocitySensor.prototype.getData = function (delay) {
        if (delay === void 0) { delay = 0; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(delay > 0)) return [3 /*break*/, 2];
                        return [4 /*yield*/, (0, utils_1.timer)(delay)];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/, [this.getTimeDomainDataInfo(), this.getRMSSpeedStatus(), this.getAccPeakStatus(), this.getFreqData()]];
                }
            });
        });
    };
    return VelocitySensor;
}());
exports.VelocitySensor = VelocitySensor;
